pub enum DestinationCleanup {
KeepExtra,
DeleteExtra,
}Expand description
How an unzip-to-S3 operation treats destination objects that are not in the ZIP.
Variants
KeepExtra
Keep destination objects that do not correspond to selected ZIP entries.
DeleteExtra
Delete destination objects under the destination prefix that are not in the ZIP.