pub enum UploadProgress {
Planned {
total_files: usize,
total_bytes: u64,
},
FileStarted {
current_file: usize,
total_files: usize,
processed_files: usize,
processed_bytes: u64,
total_bytes: u64,
path: String,
},
FileProgress {
current_file: usize,
total_files: usize,
processed_files: usize,
processed_bytes: u64,
total_bytes: u64,
path: String,
},
FileFinished {
processed_files: usize,
total_files: usize,
processed_bytes: u64,
total_bytes: u64,
path: String,
},
Finished {
total_files: usize,
total_bytes: u64,
},
}Expand description
Progress event emitted while preparing and streaming an upload ZIP.
Variants
Planned
The source has been scanned and the total entry count is known.
Fields
FileStarted
A file or preserved directory entry has started streaming into the ZIP writer.
Fields
FileProgress
A file is still streaming and byte progress has advanced.
Fields
FileFinished
One file or preserved directory entry has finished streaming into the ZIP writer.
Fields
Finished
ZIP production has finished writing into the upload pipe.
S3 multipart upload completion may still be in progress when this event is emitted.