pub struct LocalZipOptions { /* private fields */ }Expand description
Options for zipping a local directory to a local ZIP file.
Implementations
Sourceimpl LocalZipOptions
impl LocalZipOptions
Sourcepub fn new(
source_dir: impl Into<PathBuf>,
destination_zip: impl Into<PathBuf>,
) -> Self
pub fn new( source_dir: impl Into<PathBuf>, destination_zip: impl Into<PathBuf>, ) -> Self
Creates options for a local source directory and local destination ZIP.
Sourcepub fn without_catalog(self) -> Self
pub fn without_catalog(self) -> Self
Omits the embedded update catalog from the ZIP.
Sourcepub fn with_compression(self, compression: ZipCompression) -> Self
pub fn with_compression(self, compression: ZipCompression) -> Self
Sets the compression method used for regular file entries.
Sourcepub fn with_progress(
self,
callback: impl Fn(UploadProgress) + Send + Sync + 'static,
) -> Self
pub fn with_progress( self, callback: impl Fn(UploadProgress) + Send + Sync + 'static, ) -> Self
Sets the progress callback invoked during upload preparation and ZIP streaming.
Sourcepub fn with_progress_handler(self, progress: UploadProgressHandler) -> Self
pub fn with_progress_handler(self, progress: UploadProgressHandler) -> Self
Sets the progress handler invoked during upload preparation and ZIP streaming.