pub struct S3PrefixUploadOptions { /* private fields */ }Expand description
Options for zipping an S3 prefix and uploading it as an S3 ZIP object.
Implementations
Sourceimpl S3PrefixUploadOptions
impl S3PrefixUploadOptions
Sourcepub fn new(source: S3Prefix, destination: S3Object) -> Self
pub fn new(source: S3Prefix, destination: S3Object) -> Self
Creates upload options for an S3 source prefix and destination object.
Sourcepub fn without_catalog(self) -> Self
pub fn without_catalog(self) -> Self
Omits the embedded update catalog from the ZIP.
Sourcepub fn with_compression(self, compression: ZipCompression) -> Self
pub fn with_compression(self, compression: ZipCompression) -> Self
Sets the compression method used for regular file entries.
Sourcepub fn with_body_chunk_size(self, body_chunk_size: usize) -> Self
pub fn with_body_chunk_size(self, body_chunk_size: usize) -> Self
Sets the buffer size used when streaming the ZIP body to S3.
Sourcepub fn with_pipe_capacity(self, pipe_capacity: usize) -> Self
pub fn with_pipe_capacity(self, pipe_capacity: usize) -> Self
Sets the in-memory pipe capacity between ZIP production and S3 upload.
Sourcepub fn with_progress(
self,
callback: impl Fn(UploadProgress) + Send + Sync + 'static,
) -> Self
pub fn with_progress( self, callback: impl Fn(UploadProgress) + Send + Sync + 'static, ) -> Self
Sets the progress callback invoked during source listing and ZIP streaming.
Sourcepub fn with_progress_handler(self, progress: UploadProgressHandler) -> Self
pub fn with_progress_handler(self, progress: UploadProgressHandler) -> Self
Sets the progress handler invoked during source listing and ZIP streaming.