SourceDiagnostics

Struct SourceDiagnostics 

pub struct SourceDiagnostics {
Show 20 fields pub source_zip_bytes: u64, pub planned_entries: u64, pub planned_blocks: u64, pub fetched_blocks: u64, pub source_get_attempts: u64, pub source_get_retries: u64, pub source_get_request_errors: u64, pub source_get_body_errors: u64, pub source_get_short_body_errors: u64, pub source_get_errors: u64, pub planned_source_bytes: u64, pub fetched_source_bytes: u64, pub unique_source_bytes: u64, pub source_amplification: f64, pub block_hits: u64, pub block_waits: u64, pub block_releases: u64, pub block_misses: u64, pub block_refetches: u64, pub active_gets_high_water: u64,
}
Source scheduler and ranged GetObject counters.

Fields

source_zip_bytes: u64

Source ZIP object size in bytes.

planned_entries: u64

Number of ZIP entries included in source plans.

planned_blocks: u64

Number of source blocks included in source plans.

fetched_blocks: u64

Number of source blocks fetched successfully.

source_get_attempts: u64

Total ranged GetObject attempts, including retries.

source_get_retries: u64

Total ranged GetObject retries.

source_get_request_errors: u64

Ranged GetObject request errors.

source_get_body_errors: u64

Ranged GetObject response body errors.

source_get_short_body_errors: u64

Ranged GetObject responses that ended before the requested bytes were read.

source_get_errors: u64

Source block fetches that failed after all retry attempts.

planned_source_bytes: u64

Sum of planned source block sizes.

fetched_source_bytes: u64

Sum of fetched source block sizes.

unique_source_bytes: u64

Unique source bytes covered by fetched ranges.

source_amplification: f64

Ratio of fetched source bytes to unique fetched source bytes.

block_hits: u64

Number of block read requests served from ready blocks.

block_waits: u64

Number of block read requests that waited for scheduled data.

block_releases: u64

Number of ready source blocks released from the resident window after all planned claims consumed them.

block_misses: u64

Number of reader cache misses. This should remain zero for the planned source scheduler.

block_refetches: u64

Number of explicit replay fetches for blocks that had already been released from the resident window.

active_gets_high_water: u64

Highest number of concurrent ranged GetObject requests.